@@ -1,4 +1,4 @@
 .onLoad <- function(libname, pkgname) {
-   options(java.parameters = "- Xmx10000000m") 
+  options(java.parameters = "-Xmx1g") 
   rJava::.jpackage(pkgname, lib.loc = libname)
-}
\ No newline at end of file
+}
