@@ -1,7 +1,7 @@
 package ch.fgcz.proteomics.dto;
 
-/**
- * @author Lucas Schmidt
+/*
+  @author Lucas Schmidt
  * @since 2017-08-22
  */
 
@@ -9,7 +9,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 public class MassSpecMeasure {
-    private List<MassSpectrum> massSpectrumList = new ArrayList<MassSpectrum>();
+    private List<MassSpectrum> massSpectrumList;
     private String source;
 
     public String getSource() {
@@ -22,27 +22,27 @@ public class MassSpecMeasure {
 
     public MassSpecMeasure(String source) {
         this.source = source;
-        this.massSpectrumList = new ArrayList<MassSpectrum>();
+        this.massSpectrumList = new ArrayList<>();
     }
 
     public void addMS(double[] mz, double[] intensity, double peptideMass, int chargeState, int id) {
-        List<Double> mzValues = new ArrayList<Double>();
-        List<Double> intensityValues = new ArrayList<Double>();
+        List<Double> mzValues = new ArrayList<>();
+        List<Double> intensityValues = new ArrayList<>();
 
         for (int i = 0; i < mz.length || i < intensity.length; i++) {
             mzValues.add(mz[i]);
             intensityValues.add(intensity[i]);
         }
 
-        this.getMSlist().add(new MassSpectrum(mzValues, intensityValues, peptideMass, chargeState, id));
+        massSpectrumList.add(new MassSpectrum(mzValues, intensityValues, peptideMass, chargeState, id));
     }
 
     public void addMS(List<Double> mz, List<Double> intensity, double peptidMass, int chargeState, int id) {
-        this.getMSlist().add(new MassSpectrum(mz, intensity, peptidMass, chargeState, id));
+        massSpectrumList.add(new MassSpectrum(mz, intensity, peptidMass, chargeState, id));
     }
 
     public void addMS(List<Double> mz, List<Double> intensity, double peptidMass, int chargeState, int id,
             List<Integer> charge, List<Double> isotope) {
-        this.getMSlist().add(new MassSpectrum(mz, intensity, peptidMass, chargeState, id, charge, isotope));
+        massSpectrumList.add(new MassSpectrum(mz, intensity, peptidMass, chargeState, id, charge, isotope));
     }
 }
\ No newline at end of file
