@@ -17,6 +17,7 @@ public class FindNearestNeighbor {
                 index[i] = -(index[i]) - 1;
 
             if (index[i] == 0) {
+                // do nothing
             } else if (index[i] >= data.length) {
                 index[i] = index[i] - 1;
             } else {
@@ -31,4 +32,8 @@ public class FindNearestNeighbor {
 
         return index;
     }
+
+    private FindNearestNeighbor() {
+        throw new IllegalStateException("Find nearest neighbor utilities class");
+    }
 }
